##
##  calc.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         calc
Summary:      C-Style Arbitrary Precision Calculator
URL:          http://www.isthe.com/chongo/tech/comp/calc/
Vendor:       David I. Bell et al.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        BASE
Group:        Algorithm
License:      GPL
Version:      2.15.1.0
Release:      20240712

#   list of sources
Source0:      http://download.sourceforge.net/calc/calc-%{version}.tar.bz2

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101, make, gcc
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Calc is an interactive calculator which provides for easy large
    numeric calculations, but which also can be easily programmed
    for difficult or long calculations. It can accept a command line
    argument, in which case it executes that single command and exits.
    Otherwise, it enters interactive mode. In this mode, it accepts
    commands one at a time, processes them, and displays the answers.
    In the simplest case, commands are simply expressions which are
    evaluated.

%track
    prog calc = {
        version   = %{version}
        url       = http://sourceforge.net/projects/calc/files/
        regex     = calc-(__VER__)\.tar\.bz2
    }

%prep
    %setup -q

%build
    chmod -R u+w .
    %{l_shtool} subst -e "s;<malloc.h>;<stdlib.h>;" *.[ch]
    %{l_make} %{l_mflags} \
        SHELL="%{l_bash}" \
        CC="%{l_cc} %{l_cflags -O} %{l_cppflags} %{l_ldflags}" \
        BINDIR=%{l_prefix}/bin \
        LIBDIR=%{l_prefix}/lib/calc \
        INCDIR=%{l_prefix}/include \
        MANDIR=%{l_prefix}/man/man1 \
        CALC_SHAREDIR=%{l_prefix}/share/calc

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib \
        $RPM_BUILD_ROOT%{l_prefix}/man/man1
    %{l_make} %{l_mflags} install \
        SHELL="%{l_bash}" \
        BINDIR=$RPM_BUILD_ROOT%{l_prefix}/bin \
        LIBDIR=$RPM_BUILD_ROOT%{l_prefix}/lib/calc \
        INCDIR=$RPM_BUILD_ROOT%{l_prefix}/include \
        MANDIR=$RPM_BUILD_ROOT%{l_prefix}/man/man1 \
        CALC_SHAREDIR=$RPM_BUILD_ROOT%{l_prefix}/share/calc
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/include
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/lib
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share/calc/test*
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/bin/cscript
    chmod u+w $RPM_BUILD_ROOT%{l_prefix}/bin/*
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* 2>/dev/null || true
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

